@@ -2,9 +2,9 @@ import io
 import json
 import mimetypes
 
-from sentry_sdk._compat import text_type
+from sentry_sdk._compat import text_type, PY2
 from sentry_sdk._types import MYPY
-from sentry_sdk.sessions import Session
+from sentry_sdk.session import Session
 from sentry_sdk.utils import json_dumps, capture_internal_exceptions
 
 if MYPY:
@@ -18,6 +18,14 @@ if MYPY:
     from sentry_sdk._types import Event, EventDataCategory
 
 
+def parse_json(data):
+    # type: (Union[bytes, text_type]) -> Any
+    # on some python 3 versions this needs to be bytes
+    if not PY2 and isinstance(data, bytes):
+        data = data.decode("utf-8", "replace")
+    return json.loads(data)
+
+
 class Envelope(object):
     def __init__(
         self,
@@ -62,6 +70,12 @@ class Envelope(object):
             session = session.to_json()
         self.add_item(Item(payload=PayloadRef(json=session), type="session"))
 
+    def add_sessions(
+        self, sessions  # type: Any
+    ):
+        # type: (...) -> None
+        self.add_item(Item(payload=PayloadRef(json=sessions), type="sessions"))
+
     def add_item(
         self, item  # type: Item
     ):
@@ -108,7 +122,7 @@ class Envelope(object):
         cls, f  # type: Any
     ):
         # type: (...) -> Envelope
-        headers = json.loads(f.readline())
+        headers = parse_json(f.readline())
         items = []
         while 1:
             item = Item.deserialize_from(f)
@@ -230,6 +244,8 @@ class Item(object):
             return "transaction"
         elif ty == "event":
             return "error"
+        elif ty == "client_report":
+            return "internal"
         else:
             return "default"
 
@@ -278,14 +294,19 @@ class Item(object):
         line = f.readline().rstrip()
         if not line:
             return None
-        headers = json.loads(line)
-        length = headers["length"]
-        payload = f.read(length)
-        if headers.get("type") in ("event", "transaction"):
-            rv = cls(headers=headers, payload=PayloadRef(json=json.loads(payload)))
+        headers = parse_json(line)
+        length = headers.get("length")
+        if length is not None:
+            payload = f.read(length)
+            f.readline()
+        else:
+            # if no length was specified we need to read up to the end of line
+            # and remove it (if it is present, i.e. not the very last char in an eof terminated envelope)
+            payload = f.readline().rstrip(b"\n")
+        if headers.get("type") in ("event", "transaction", "metric_buckets"):
+            rv = cls(headers=headers, payload=PayloadRef(json=parse_json(payload)))
         else:
             rv = cls(headers=headers, payload=payload)
-        f.readline()
         return rv
 
     @classmethod
