@@ -65,9 +65,7 @@ class AioHttpIntegration(Integration):
         try:
             version = tuple(map(int, AIOHTTP_VERSION.split(".")[:2]))
         except (TypeError, ValueError):
-            raise DidNotEnable(
-                "AIOHTTP version unparseable: {}".format(AIOHTTP_VERSION)
-            )
+            raise DidNotEnable("AIOHTTP version unparsable: {}".format(AIOHTTP_VERSION))
 
         if version < (3, 4):
             raise DidNotEnable("AIOHTTP 3.4 or newer required.")
@@ -92,7 +90,7 @@ class AioHttpIntegration(Integration):
 
             weak_request = weakref.ref(request)
 
-            with Hub(Hub.current) as hub:
+            with Hub(hub) as hub:
                 # Scope data will not leak between requests because aiohttp
                 # create a task to wrap each request.
                 with hub.configure_scope() as scope:
