@@ -1,3 +1,4 @@
+import base64
 import json
 import linecache
 import logging
@@ -5,6 +6,7 @@ import os
 import sys
 import threading
 import subprocess
+import re
 
 from datetime import datetime
 
@@ -39,6 +41,7 @@ logger = logging.getLogger("sentry_sdk.errors")
 
 MAX_STRING_LENGTH = 512
 MAX_FORMAT_PARAM_LENGTH = 128
+BASE64_ALPHABET = re.compile(r"^[a-zA-Z0-9/+=]*$")
 
 
 def json_dumps(data):
@@ -64,7 +67,7 @@ def get_default_release():
         try:
             release = (
                 subprocess.Popen(
-                    ["git", "rev-parse", "--short", "HEAD"],
+                    ["git", "rev-parse", "HEAD"],
                     stdout=subprocess.PIPE,
                     stderr=null,
                     stdin=null,
@@ -92,18 +95,6 @@ def get_default_release():
     return None
 
 
-def get_default_environment(
-    release=None,  # type: Optional[str]
-):
-    # type: (...) -> Optional[str]
-    rv = os.environ.get("SENTRY_ENVIRONMENT")
-    if rv:
-        return rv
-    if release is not None:
-        return "production"
-    return None
-
-
 class CaptureInternalException(object):
     __slots__ = ()
 
@@ -797,12 +788,26 @@ def _is_contextvars_broken():
     Returns whether gevent/eventlet have patched the stdlib in a way where thread locals are now more "correct" than contextvars.
     """
     try:
+        import gevent  # type: ignore
         from gevent.monkey import is_object_patched  # type: ignore
 
+        # Get the MAJOR and MINOR version numbers of Gevent
+        version_tuple = tuple(
+            [int(part) for part in re.split(r"a|b|rc|\.", gevent.__version__)[:2]]
+        )
         if is_object_patched("threading", "local"):
-            # Gevent 20.5 is able to patch both thread locals and contextvars,
-            # in that case all is good.
-            if is_object_patched("contextvars", "ContextVar"):
+            # Gevent 20.9.0 depends on Greenlet 0.4.17 which natively handles switching
+            # context vars when greenlets are switched, so, Gevent 20.9.0+ is all fine.
+            # Ref: https://github.com/gevent/gevent/blob/83c9e2ae5b0834b8f84233760aabe82c3ba065b4/src/gevent/monkey.py#L604-L609
+            # Gevent 20.5, that doesn't depend on Greenlet 0.4.17 with native support
+            # for contextvars, is able to patch both thread locals and contextvars, in
+            # that case, check if contextvars are effectively patched.
+            if (
+                # Gevent 20.9.0+
+                (sys.version_info >= (3, 7) and version_tuple >= (20, 9))
+                # Gevent 20.5.0+ or Python < 3.7
+                or (is_object_patched("contextvars", "ContextVar"))
+            ):
                 return False
 
             return True
@@ -968,3 +973,42 @@ class TimeoutThread(threading.Thread):
                 integer_configured_timeout
             )
         )
+
+
+def to_base64(original):
+    # type: (str) -> Optional[str]
+    """
+    Convert a string to base64, via UTF-8. Returns None on invalid input.
+    """
+    base64_string = None
+
+    try:
+        utf8_bytes = original.encode("UTF-8")
+        base64_bytes = base64.b64encode(utf8_bytes)
+        base64_string = base64_bytes.decode("UTF-8")
+    except Exception as err:
+        logger.warning("Unable to encode {orig} to base64:".format(orig=original), err)
+
+    return base64_string
+
+
+def from_base64(base64_string):
+    # type: (str) -> Optional[str]
+    """
+    Convert a string from base64, via UTF-8. Returns None on invalid input.
+    """
+    utf8_string = None
+
+    try:
+        only_valid_chars = BASE64_ALPHABET.match(base64_string)
+        assert only_valid_chars
+
+        base64_bytes = base64_string.encode("UTF-8")
+        utf8_bytes = base64.b64decode(base64_bytes)
+        utf8_string = utf8_bytes.decode("UTF-8")
+    except Exception as err:
+        logger.warning(
+            "Unable to decode {b64} from base64:".format(b64=base64_string), err
+        )
+
+    return utf8_string
